@@ -1,19 +1,35 @@
 /*
-   Copyright 2007 - 2008 MySQL AB, 2008 - 2010 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+
+
 #ifndef _MYSQL_PREPARED_STATEMENT_H_
 #define _MYSQL_PREPARED_STATEMENT_H_
 
 #include <boost/scoped_ptr.hpp>
 #include <boost/shared_ptr.hpp>
+
 #include <cppconn/prepared_statement.h>
 #include <cppconn/parameter_metadata.h>
 
@@ -27,6 +43,7 @@ class MySQL_ParamBind;
 class MySQL_ParameterMetaData;
 class MySQL_PreparedResultSetMetaData;
 class MySQL_ResultBind;
+class MySQL_Warning;
 
 namespace NativeAPI
 {
@@ -45,9 +62,10 @@ protected:
 	int resultSetConcurrency;
 	int resultSetType;
 
-	boost::scoped_ptr< sql::SQLWarning > warnings;
+	boost::scoped_ptr< MySQL_Warning > warnings;
 
 	bool isClosed;
+	bool warningsHaveBeenLoaded;
 
 	boost::shared_ptr< MySQL_DebugLogger > logger;
 
@@ -58,12 +76,13 @@ protected:
 
 	boost::shared_ptr< MySQL_ResultBind > result_bind;
 
+	unsigned int warningsCount;
+
 	virtual void do_query();
 	virtual void checkClosed();
 	virtual void closeIntern();
 
 	bool sendLongDataBeforeParamBind();
-	void setBlob_intern(unsigned int parameterIndex, std::istream * blob, bool deleteBlobAfterExecute);
 
 public:
 
