@@ -1,15 +1,30 @@
 /*
-   Copyright 2007 - 2008 MySQL AB, 2008 - 2010 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
 
+
+
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
@@ -109,8 +124,15 @@ MySQL_ResultSetMetaData::getColumnDisplaySize(unsigned int columnIndex)
 	CPP_ENTER("MySQL_ResultSetMetaData::getColumnDisplaySize");
 	checkValid();
 	checkColumnIndex(columnIndex);
+	const MYSQL_FIELD * const field = getFieldMeta(columnIndex);
+	const sql::mysql::util::OUR_CHARSET * const cs = sql::mysql::util::find_charset(field->charsetnr);
+	if (!cs) {
+		std::ostringstream msg("Server sent uknown charsetnr (");
+		msg << field->charsetnr << ") . Please report";
+		throw SQLException(msg.str());
+	}
+	int ret = field->length / cs->char_maxlen;
 
-	int ret = getFieldMeta(columnIndex)->length;
 	CPP_INFO_FMT("column=%u name=%s display_size=%d", columnIndex, getFieldMeta(columnIndex)->name, ret);
 	return ret;
 }
@@ -164,7 +186,7 @@ MySQL_ResultSetMetaData::getColumnTypeName(unsigned int columnIndex)
 	checkValid();
 	checkColumnIndex(columnIndex);
 
-	return sql::mysql::util::mysql_type_to_string(getFieldMeta(columnIndex));
+	return sql::mysql::util::mysql_type_to_string(getFieldMeta(columnIndex), this->logger);
 }
 /* }}} */
 
@@ -312,6 +334,19 @@ MySQL_ResultSetMetaData::isNullable(unsigned int columnIndex)
 /* }}} */
 
 
+/* {{{ MySQL_ResultSetMetaData::isNumeric -I- */
+bool
+MySQL_ResultSetMetaData::isNumeric(unsigned int columnIndex)
+{
+	CPP_ENTER("MySQL_ResultSetMetaData::isNumeric");
+	checkValid();
+	checkColumnIndex(columnIndex);
+
+	return (getFieldMeta(columnIndex)->flags & NUM_FLAG) != 0;
+}
+/* }}} */
+
+
 /* {{{ MySQL_ResultSetMetaData::isReadOnly -I- */
 bool
 MySQL_ResultSetMetaData::isReadOnly(unsigned int columnIndex)
