@@ -1,20 +1,36 @@
 /*
-   Copyright 2007 - 2008 MySQL AB, 2008 - 2010 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
+
+
 #ifndef _MYSQL_UTIL_H_
 #define _MYSQL_UTIL_H_
 
 #include "nativeapi/mysql_private_iface.h"
 #include <cppconn/config.h>
 #include <cppconn/sqlstring.h>
+#include <boost/shared_ptr.hpp>
 
 
 #ifndef UL64
@@ -33,6 +49,7 @@
 #endif
 #endif
 
+#define NULLCSTR static_cast<char *>(0)
 
 #ifndef _WIN32
 #  ifndef HAVE_FUNCTION_STRTOLL
@@ -44,8 +61,12 @@
 #    define HAVE_FUNCTION_STRTOULL 1
 #  endif
 #else
+# ifndef strtoll
 #  define strtoll(x, e, b) _strtoi64((x), (e), (b))
+# endif
+# ifndef strtoull
 #  define strtoull(x, e, b) _strtoui64((x), (e), (b))
+# endif
 #endif	//	_WIN32
 
 
@@ -94,20 +115,27 @@ namespace sql
 {
 namespace mysql
 {
+
+class MySQL_DebugLogger;
+
 namespace NativeAPI
 {
 class NativeConnectionWrapper;
 class NativeStatementWrapper;
 } /* namespace NativeAPI */
 
+
 namespace util {
 
+extern const sql::SQLString EMPTYSTR;
+extern const sql::SQLString LOCALHOST;
+
 void throwSQLException(::sql::mysql::NativeAPI::NativeConnectionWrapper & proxy);
 void throwSQLException(::sql::mysql::NativeAPI::NativeStatementWrapper & proxy);
 
 int mysql_string_type_to_datatype(const sql::SQLString & name);
 int mysql_type_to_datatype(const MYSQL_FIELD * const field);
-const char * mysql_type_to_string(const MYSQL_FIELD * const field);
+const char * mysql_type_to_string(const MYSQL_FIELD * const field, boost::shared_ptr< sql::mysql::MySQL_DebugLogger > & l);
 
 char * utf8_strup(const char * const src, size_t srclen);
 
