@@ -1,13 +1,28 @@
 /*
-   Copyright 2007 - 2008 MySQL AB, 2008 - 2009 Sun Microsystems, Inc.  All rights reserved.
+Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
+
+The MySQL Connector/C++ is licensed under the terms of the GPLv2
+<http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
+MySQL Connectors. There are special exceptions to the terms and
+conditions of the GPLv2 as it is applied to this software, see the
+FLOSS License Exception
+<http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published
+by the Free Software Foundation; version 2 of the License.
+
+This program is distributed in the hope that it will be useful, but
+WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
+for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+*/
+
 
-   The MySQL Connector/C++ is licensed under the terms of the GPL
-   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-   MySQL Connectors. There are special exceptions to the terms and
-   conditions of the GPL as it is applied to this software, see the
-   FLOSS License Exception
-   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
- */
 
 #include <time.h>
 #include <stdlib.h>
@@ -216,7 +231,7 @@ hasSps(true)
 
 
 void BaseTestFixture::createStandardTable(standard_tables table)
-{  
+{
   try {
   switch (table) {
   case TABLE_CTSTABLE1:
@@ -261,7 +276,7 @@ void BaseTestFixture::createStandardTable(standard_tables table)
   case TABLE_BIGINTTAB:
     createTable("Bigint_Tab", "(MAX_VAL bigint(20) default NULL, MIN_VAL bigint(20) default NULL, NULL_VAL bigint(20) default NULL) ENGINE=InnoDB");
     break;
-    
+
   case TABLE_CHARTAB:
     createTable("Char_Tab", "(COFFEE_NAME char(30) default NULL, NULL_VAL char(30) default NULL) ENGINE=InnoDB");
     break;
@@ -278,17 +293,17 @@ void BaseTestFixture::createStandardTable(standard_tables table)
     createTable("Smallint_Tab", "(MAX_VAL smallint(6) default NULL, MIN_VAL smallint(6) default NULL,  NULL_VAL smallint(6) default NULL) ENGINE=InnoDB");
     break;
 
-  case TABLE_LONGVARCHARNULLTAB:    
+  case TABLE_LONGVARCHARNULLTAB:
     createTable("Longvarcharnull_Tab", "(NULL_VAL mediumtext) ENGINE=InnoDB");
     break;
 
   }
 
-  } catch (sql::SQLException &e) {    
+  } catch (sql::SQLException &e) {
     logErr(e.what());
     fail(e.what(), __FILE__, __LINE__);
   }
-  
+
 }
 /* throws SQLException & */
 void BaseTestFixture::createSchemaObject(String objectType, String objectName,
@@ -308,7 +323,7 @@ void BaseTestFixture::createSchemaObject(String objectType, String objectName,
   createSql.append(" ");
   createSql.append(objectName);
   createSql.append(" ");
-  createSql.append(columnsAndOtherStuff);  
+  createSql.append(columnsAndOtherStuff);
   this->stmt->executeUpdate(createSql);
 }
 
